@@ -23,8 +23,5 @@ def init_app(app, settings):
 
 
 def _init_sqlalchemy(app, settings):
+    app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
     db.init_app(app)
-    do_wrap = settings.get_by_prefix('guniflask.wrap_sqlalchemy_model', True)
-    if do_wrap:
-        from guniflask.orm import wrap_sqlalchemy_model
-        wrap_sqlalchemy_model(db.Model)
